@@ -86,7 +86,11 @@ class RoborockBase:
     def as_dict(self) -> dict:
         return asdict(
             self,
-            dict_factory=lambda _fields: {camelize(key): value for (key, value) in _fields if value is not None},
+            dict_factory=lambda _fields: {
+                camelize(key): value.value if isinstance(value, Enum) else value
+                for (key, value) in _fields
+                if value is not None
+            },
         )
 
 
@@ -380,13 +384,17 @@ class Consumable(RoborockBase):
 
     def __post_init__(self):
         self.main_brush_time_left = (
-            MAIN_BRUSH_REPLACE_TIME - self.main_brush_work_time if self.main_brush_work_time else None
+            MAIN_BRUSH_REPLACE_TIME - self.main_brush_work_time if self.main_brush_work_time is not None else None
         )
         self.side_brush_time_left = (
-            SIDE_BRUSH_REPLACE_TIME - self.side_brush_work_time if self.side_brush_work_time else None
+            SIDE_BRUSH_REPLACE_TIME - self.side_brush_work_time if self.side_brush_work_time is not None else None
+        )
+        self.filter_time_left = (
+            FILTER_REPLACE_TIME - self.filter_work_time if self.filter_work_time is not None else None
+        )
+        self.sensor_time_left = (
+            SENSOR_DIRTY_REPLACE_TIME - self.sensor_dirty_time if self.sensor_dirty_time is not None else None
         )
-        self.filter_time_left = FILTER_REPLACE_TIME - self.filter_work_time if self.filter_work_time else None
-        self.sensor_time_left = SENSOR_DIRTY_REPLACE_TIME - self.sensor_dirty_time if self.sensor_dirty_time else None
 
 
 @dataclass
